@@ -3,66 +3,32 @@ package Clustericious::App;
 use strict;
 use warnings;
 use 5.010;
-use List::Util qw/first/;
-use List::MoreUtils qw/uniq/;
+use List::Util qw( first );
 use MojoX::Log::Log4perl;
 use Mojo::UserAgent;
-use Clustericious::Templates;
-use Mojo::ByteStream qw/b/;
+use Mojo::ByteStream qw( b );
 use Data::Dumper;
 use Clustericious::Log;
 use Mojo::URL;
-use Scalar::Util qw/weaken/;
+use Scalar::Util qw( weaken );
 use Mojo::Base 'Mojolicious';
 use File::HomeDir ();
-use Carp qw( cluck );
+use Carp qw( cluck croak carp );
 use Clustericious;
 use Clustericious::Controller;
-use Clustericious::Renderer;
-use Clustericious::RouteBuilder::Common;
 use Clustericious::Config;
 use Clustericious::Commands;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.10_01'; # TRIAL VERSION
-
-
-sub _have_rose {
-    return 1 if Rose::Planter->can("tables");
-}
+our $VERSION = '1.10_02'; # TRIAL VERSION
 
 
 has commands => sub {
   my $commands = Clustericious::Commands->new(app => shift);
-    weaken $commands->{app};
-    return $commands;
+  weaken $commands->{app};
+  return $commands;
 };
 
-our @Confdirs = (File::HomeDir->my_home, File::HomeDir->my_home . "/etc", "/util/etc", "/etc" );
-
-if($ENV{TEST_HARNESS} && $ENV{CLUSTERICIOUS_TEST_CONF_DIR})
-{
-  cluck 'Instead of using CLUSTERICIOUS_TEST_CONF_DIR environment variable, ' .
-        'try Test::Clustericious::Config or Test::Clustericious::Cluster';
-}
-
-{
-no warnings 'redefine';
-sub Math::BigInt::TO_JSON {
-    my $val = shift;
-    my $copy = "$val";
-    my $i = 0 + $copy;
-    return $i;
-}
-}
-
-
-my @route_builders;
-
-sub _add_route_builder
-{
-  push @route_builders, $_[1];
-}
 
 sub startup {
     my $self = shift;
@@ -75,22 +41,14 @@ sub startup {
     );
 
     $self->controller_class('Clustericious::Controller');
-    $self->renderer(Clustericious::Renderer->new());
-    $self->renderer->classes([qw/Clustericious::Templates/]);
+    $self->renderer->classes(['Clustericious::App']);
     my $home = $self->home;
     $self->renderer->paths([ $home->rel_dir('templates') ]);
 
     $self->init_logging();
-    if($self->can('secrets'))
-    {
-      $self->secrets( [ ref $self || $self ] );
-    }
-    else
-    {
-      $self->secret( (ref $self || $self) );
-    }
+    $self->secrets( [ ref $self || $self ] );
 
-    $self->plugins->namespaces(['Mojolicious::Plugin','Clustericious::Plugin']);
+    $self->plugins->namespaces(['Clustericious::Plugin','Mojolicious::Plugin']);
     my $config = $self->config;
     my $auth_plugin;
     if(my $auth_config = $config->plug_auth(default => '')) {
@@ -100,20 +58,17 @@ sub startup {
         { $name = $auth_config->{plugin} }
         $auth_plugin = $self->plugin($name, plug_auth => $auth_config);
     } elsif($auth_config = $config->simple_auth(default => '')) {
-        $self->log->info("Loading auth plugin simple_auth [deprecated]");
-        $auth_plugin = $self->plugin('plug_auth', plug_auth => $auth_config);
+        croak "Using simple_auth in configuration has been removed.  Change your configuration to use plug_auth instead.";
     } else {
         $self->log->info("No auth configured");
     }
 
-    my $r = $self->routes;
-    # "Common" ones are not overrideable.
-    Clustericious::RouteBuilder::Common->_add_routes($self);
-    $_->($self, $auth_plugin) for @route_builders;
-
+    $self->plugin('CommonRoutes');
+    $self->startup_route_builder($auth_plugin) if $self->can('startup_route_builder');
     $self->plugin('AutodataHandler');
+    
     $self->plugin('DefaultHelpers');
-    $self->plugin('TagHelpers');
+    #$self->plugin('TagHelpers');
     $self->plugin('EPLRenderer');
     $self->plugin('EPRenderer');
 
@@ -186,72 +141,25 @@ sub init_logging {
 
 
 sub dump_api {
-    my $self = shift;
-    my $routes = shift || $self->routes->children;
-    my @all;
-    for my $r (@$routes) {
-        my $pat = $r->pattern;
-        $pat->_compile;
-        my %placeholders = map { $_ => "<$_>" } @{ $pat->placeholders };
-        my $method = uc join ',', @{ $r->via || ["GET"] };
-        if (_have_rose() && $placeholders{table}) {
-            for my $table (Rose::Planter->tables) {
-                $placeholders{table} = $table;
-                my $pat = $pat->unparsed;
-                $pat =~ s/:table/$table/;
-                push @all, "$method $pat";
-            }
-        } elsif (_have_rose() && $placeholders{items}) {
-            for my $plural (Rose::Planter->plurals) {
-                $placeholders{items} = $plural;
-                my $line = $pat->render(\%placeholders);
-                push @all, "$method $line";
-            }
-        } elsif (defined($pat->unparsed)) {
-            push @all, join ' ', $method, $pat->unparsed;
-        } else {
-            push @all, $self->dump_api($r->children);
-        }
-    }
-    return uniq sort @all;
+  carp "Clustericious::App#dump_api is deprecated";
+  require Clustericious::Plugin::CommonRoutes;
+  Clustericious::Plugin::CommonRoutes->_dump_api(@_);
 }
 
 
 sub _dump_api_table_types
 {
-    my($rose_type) = @_;
-    return 'datetime' if $rose_type =~ /^datetime/;
-    state $types = {
-        (map { $_ => 'string' } qw( character text varchar )),
-        (map { $_ => 'numeric' } 'numeric', 'float', 'double precision','decimal'),
-        (map { $_ => $_ } qw( blob set time interval enum bytea chkpass bitfield date boolean )),
-        (map { $_ => 'integer' } qw( bigint integer bigserial serial )),
-        (map { $_ => 'epoch' } 'epoch', 'epoch hires'),
-        (map { $_ => 'timestamp' } 'timestamp', 'timestamp with time zone'),
-    };
-    return $types->{$rose_type} // 'unknown';
+  carp "Clustericious::App#dump_api_table is deprecated";
+  require Clustericious::Plugin::CommonRoutes;
+  Clustericious::Plugin::CommonRoutes->_dump_api_table_types(@_);
+  
 }
 
 sub dump_api_table
 {
-    my($self, $table) = @_;
-    return unless _have_rose();
-    my $class = Rose::Planter->find_class($table);
-    return unless defined $class;
-
-    return {
-        columns => {
-            map {
-                $_->name => {
-                    rose_db_type => $_->type,
-                    not_null     => $_->not_null,
-                    type         => _dump_api_table_types($_->type),
-                } } $class->meta->columns
-            },
-        primary_key => [
-            map { $_->name } $class->meta->primary_key_columns
-        ],
-    };
+  carp "Clustericious::App#dump_api_table is deprecated";
+  require Clustericious::Plugin::CommonRoutes;
+  Clustericious::Plugin::CommonRoutes->_dump_api_table($_[1]);
 }
 
 
@@ -296,22 +204,20 @@ sub config {
 
 sub sanity_check
 {
-    my($self) = @_;
-
-    my $sane = 1;
+  my($self) = @_;
+  my $sane = 1;
+  
+  if(my $error = $self->config->clustericious_config_error(default => ''))
+  {
+    say "error loading configuration: $error";
+    $sane = 0;
+  }
     
-    if(my $error = $self->config->clustericious_config_error(default => '')) {
-        say "error loading configuration: $error";
-        $sane = 0;
-    }
-    
-    $sane;
+  $sane;
 }
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -322,7 +228,7 @@ Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.10_01
+version 1.10_02
 
 =head1 SYNOPSIS
 
@@ -346,28 +252,44 @@ An instance of L<Clustericious::Commands> for use with this application.
 
 =head1 METHODS
 
-=head2 $app-E<gt>startup
+=head2 startup
+
+ $app->startup;
 
 Adds the autodata_handler plugin, common routes,
 and sets up logging for the client using log::log4perl.
 
-=head2 $app-E<gt>init_logging
+=head2 init_logging
+
+ $app->init_logging;
 
 Initializing logging using ~/etc/log4perl.conf
 
-=head2 $app-E<gt>dump_api
+=head2 dump_api
+
+ my @api = $app->dump_api;
+
+B<DEPRECATED>: will be removed on or after January 31, 2016.
 
 Dump out the API for this REST server.
 
-=head2 $app-E<gt>dump_api_table( $table )
+=head2 dump_api_table
+
+ my $api = $app->dump_api_table( $table );
+
+B<DEPRECATED>: will be removed on or after January 31, 2016.
 
 Dump out the column information for the given table.
 
-=head2 $app-E<gt>config
+=head2 config
+
+ my $config = $app->config;
 
 Returns the config (an instance of L<Clustericious::Config>) for the application.
 
-=head2 $app-E<gt>sanity_check
+=head2 sanity_check
+
+ my $ok = $app->sanity_check;
 
 This method is executed after C<startup>, but before the application
 actually starts with the L<start|Clustericious::Command::start> command.
@@ -405,3 +327,28 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__DATA__
+
+@@ not_found.html.ep
+NOT FOUND: "<%= $self->req->url->path || '/' %>"
+
+@@ not_found.development.html.ep
+NOT FOUND: "<%= $self->req->url->path || '/' %>"
+
+@@ layouts/default.html.ep
+<!doctype html><html>
+  <head><title>Welcome</title></head>
+  <body><%== content %></body>
+</html>
+
+@@ exception.html.ep
+% my $s = $self->stash;
+% my $e = $self->stash('exception');
+% delete $s->{inner_template};
+% delete $s->{exception};
+% my $dump = dumper $s;
+% $s->{exception} = $e;
+% use Mojo::ByteStream qw/b/;
+ERROR: <%= b($e); %>
+
