@@ -9,7 +9,7 @@ use YAML::XS qw/Dump Load/;
 use Clustericious::Log;
 
 # ABSTRACT: Handle data types automatically
-our $VERSION = '1.10_01'; # TRIAL VERSION
+our $VERSION = '1.10_02'; # TRIAL VERSION
 
 
 my $default_decode = 'application/x-www-form-urlencoded';
@@ -54,6 +54,11 @@ sub register
     $app->plugins->on( add_autodata_type => \&_autodata_add);
 
     $app->helper( parse_autodata => \&_autodata_parse );
+    
+    $app->hook(before_render => sub {
+      my($c, $args) = @_;
+      $c->stash->{handler} = "autodata" if exists($c->stash->{autodata}) || exists($args->{autodata});
+    });
 }
 
 sub _autodata_add
@@ -135,7 +140,7 @@ Clustericious::Plugin::AutodataHandler - Handle data types automatically
 
 =head1 VERSION
 
-version 1.10_01
+version 1.10_02
 
 =head1 SYNOPSIS
 
