@@ -9,7 +9,7 @@ use Clustericious::Config;
 use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: Plugin for clustericious to use PlugAuth.
-our $VERSION = '1.10_01'; # TRIAL VERSION
+our $VERSION = '1.10_02'; # TRIAL VERSION
 
 
 has 'config_url';
@@ -34,7 +34,7 @@ sub authenticate {
     # Everyone needs to send an authorization header
     my $auth = $c->req->headers->authorization or do {
         $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
-        $c->render_text("auth required", layout => "", status => 401);
+        $c->render(text => "auth required", layout => "", status => 401);
         return;
     };
 
@@ -164,7 +164,7 @@ Clustericious::Plugin::PlugAuth - Plugin for clustericious to use PlugAuth.
 
 =head1 VERSION
 
-version 1.10_01
+version 1.10_02
 
 =head1 SYNOPSIS
 
